﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Encodings.PackingEncoding.MultiComponentVector {
  [Item("SingleGroupingMoveAttribute", "Specifies the tabu attributes for a single grouping move on an multi component vector.")]
  [StorableClass]
  public class SingleGroupingMoveAttribute : MultiComponentVectorMoveAttribute { 
    [Storable]
    public int OldGroup { get; protected set; }
    [Storable]
    public int Index { get; protected set; }
    [Storable]
    public int ItemID { get; protected set; }
    [Storable]
    public int NewGroup { get; protected set; }

    [StorableConstructor]
    protected SingleGroupingMoveAttribute(bool deserializing) : base(deserializing) { }
    protected SingleGroupingMoveAttribute(SingleGroupingMoveAttribute original, Cloner cloner)
      : base(original, cloner) {   
      this.OldGroup = original.OldGroup;
      this.Index = original.Index;
      this.ItemID = original.ItemID;
      this.NewGroup = original.NewGroup;
    }
    public SingleGroupingMoveAttribute() : this(-1, -1, -1, -1, -1) { }
    public SingleGroupingMoveAttribute(int oldGroup, int index, int itemID, int newGroup, double moveQuality)
      : base(moveQuality) {
        OldGroup = oldGroup;
      Index = index;
      ItemID = itemID;
      NewGroup = newGroup;
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new SingleGroupingMoveAttribute(this, cloner);
    }
  }
}
